@@ -590,7 +590,7 @@ sub init_reg_se {
        );
     }
 
-    $dri->add_registry( 'SE', { clid => $clid } );
+    $dri->add_registry( 'IIS', { clid => $clid } );
 
     my %pars = (
         defer               => 0,
