@@ -5,7 +5,7 @@ use warnings;
 
 use Net::DRI;
 
-my $dri=Net::DRI->new(10);
+my $dri=Net::DRI->new({cache_ttl => 10});
 
 my $ok=eval {
 ############################################################################################################
