@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of contact data for .NO
 ##
-## Copyright (c) 2008-2011,2014 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+## Copyright (c) 2008-2011,2014,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>.
 ##                    All rights reserved.
 ##
@@ -132,7 +132,7 @@ Trond Haugen, E<lt>info@norid.noE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2014 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+Copyright (c) 2008-2011,2014,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen E<lt>info@norid.noE<gt>.
 All rights reserved.
 
@@ -163,9 +163,7 @@ sub validate {
             && $self->email()
             && $self->auth()
             && $self->srid();
-        Net::DRI::Exception::usererr_insufficient_parameters(
-            'Invalid contact information: org is not allowed for .NO')
-            if ( $self->org() );
+
         Net::DRI::Exception::usererr_insufficient_parameters(
             'Invalid contact information: type mandatory')
             unless ( $self->type() );
