@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Handling of statuses list (order is irrelevant) (base class)
 ##
-## Copyright (c) 2005-2008,2010,2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2008,2010-2011,2013-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -120,7 +120,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2008,2010,2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2008,2010-2011,2013-2014 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -197,7 +197,7 @@ sub list_status
  {
   my $r=$name;
   $r.=sprintf(' (%s:%s)',$self->{sl}->{$name}->{lang},$self->{sl}->{$name}->{msg}) if exists $self->{sl}->{$name}->{lang} && $self->{sl}->{$name}->{msg};
-  my @ek=grep { ! /^(?:lang|msg)$/ } keys %{$self->{sl}->{$name}};
+  my @ek=sort { $a cmp $b } grep { ! /^(?:lang|msg)$/ } keys %{$self->{sl}->{$name}};
   $r.=join('',map { '['.$_.']' } @ek) if @ek;
   push @r,$r;
  }
