@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .AERO Domain EPP extension commands
 ##
-## Copyright (c) 2006-2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006-2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -47,7 +47,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006-2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -85,9 +85,7 @@ sub create
  push @n,['aero:ensAuthID',$rd->{ens}->{auth_id}];
  push @n,['aero:ensAuthKey',$rd->{ens}->{auth_key}];
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('aero','create');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('aero', ['create', @n]);
  return;
 }
 
