@@ -1,6 +1,6 @@
 ## Domain Registry Interface, ARNES (.SI) Contact EPP extension commands
 ##
-## Copyright (c) 2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -46,7 +46,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -79,9 +79,7 @@ sub create
 # validate() has been called
  return unless $contact->ctype();
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('dnssi','ext');
- $mes->command_extension($eid,[['dnssi:create', ['dnssi:contact',{type=>$contact->ctype()}]]]);
+ $epp->message()->command_extension('dnssi', ['ext', ['create', ['contact',{type=>$contact->ctype()}]]]);
  return;
 }
 
