@@ -1,7 +1,7 @@
 ## Domain Registry Interface, NIC.AT Contact extension
 ## Contributed by Michael Braunoeder from NIC.AT <mib@nic.at>
 ##
-## Copyright (c) 2006-2008,2010,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006-2008,2010,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -47,7 +47,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2010,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006-2008,2010,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -107,13 +107,11 @@ sub parse_info
 sub create
 {
  my ($epp,$contact,$rd)=@_;
- my $mes=$epp->message();
 
  my $type=$contact->type();
- return unless (defined($type));
+ return unless defined $type;
 
- my $eid=$mes->command_extension_register('at-ext-contact', 'create');
- $mes->command_extension($eid,['at-ext-contact:type',$type]);
+ $epp->message()->command_extension('at-ext-contact', ['create', ['type', $type]]);
  return;
 }
 
@@ -121,14 +119,10 @@ sub update
 {
  my ($epp,$contact,$todo)=@_;
 
- my $mes=$epp->message();
- my $newc=$todo->set('info');
+ my $type=$todo->set('info')->type();
+ return unless defined $type;
 
- my $type=$newc->type();
- return unless (defined($type));
-
- my $eid=$mes->command_extension_register('at-ext-contact', 'update');
- $mes->command_extension($eid,['at-ext-contact:chg',['at-ext-contact:type',$type]]);
+ $epp->message()->command_extension('at-ext-contact', ['update', ['chg', ['type', $type]]]);
  return;
 }
 
