@@ -1,7 +1,7 @@
 ## Domain Registry Interface, nic.at domain transactions extension
 ## Contributed by Michael Braunoeder from NIC.AT <mib@nic.at>
 ##
-## Copyright (c) 2006-2008,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006-2008,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -60,8 +60,6 @@ sub extonly {
       Net::DRI::Exception->die(1,'protocol/EPP',10,'Invalid domain name: '.$domain) unless Net::DRI::Util::is_hostname($domain);
       ##$mes->command_body([['domain:name',$domain]]); ## Useless if pure extension
 
-       my $eid = $mes->command_extension_register( 'at-ext-epp', 'command');
-
        my $cltrid=$mes->cltrid();
 
        if ( $transaction eq 'withdraw' ) {
@@ -73,9 +71,9 @@ sub extonly {
 				$zdhash{'value'} = $rd->{zd} ? $rd->{zd} : 0;
 
 	           $mes->command_extension(
-               $eid,
+               'at-ext-epp',
 
-                       [
+                       ['command', 
                                ['withdraw',
                                [ 'domain:withdraw',  ['domain:name', $domain], \%domns ,
                                						  ['domain:zd', \%zdhash], \%domns  ]],
@@ -103,8 +101,8 @@ sub extonly {
 
 
                $mes->command_extension(
-               $eid,
-                       [
+               'at-ext-epp',
+                       ['command', 
                                ['transfer',
 
                                        { 'op' => 'execute' },
@@ -126,35 +124,26 @@ sub extonly {
 sub delete { ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 
        my ( $epp, $domain, $rd ) = @_;
-       my $mes = $epp->message();
 
        my $scheduledate;
        $scheduledate = $rd->{scheduledate} if $rd->{scheduledate};
 
-       return unless ( defined($scheduledate) );
+       return unless defined $scheduledate;
 
-       my $eid = $mes->command_extension_register( 'at-ext-domain', 'delete');
-
-       $mes->command_extension( $eid,
-               [ 'at-ext-domain:scheduledate', $scheduledate ] );
+       $epp->message()->command_extension( 'at-ext-domain', ['delete', [ 'ascheduledate', $scheduledate ] ] );
        return;
 }
 
 sub transfer_request {
        my ( $epp, $domain, $rd ) = @_;
-       my $mes = $epp->message();
 
        my $registrarinfo;
        $registrarinfo = $rd->{registrarinfo} if $rd->{registrarinfo};
 
        return unless ( defined($registrarinfo) );
 
-       my $eid = $mes->command_extension_register( 'at-ext-domain', 'clientdata');
-
-       my %entryname;
-       $entryname{name} = 'Registrarinfo';
-       $mes->command_extension( $eid,
-               [ 'at-ext-domain:entry', \%entryname, $registrarinfo ] );
+       my %entryname = { name => 'Registrarinfo' };
+       $epp->message()->command_extension( 'at-ext-domain', ['clientdata', [ 'entry', \%entryname, $registrarinfo ]] );
        return;
 }
 
@@ -209,7 +198,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006-2008,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
