@@ -1,7 +1,7 @@
 ## Domain Registry Interface, ENUM.AT Options extension
 ## Contributed by Michael Braunoeder from ENUM.AT <michael.braunoeder@enum.at>
 ##
-## Copyright (c) 2006,2008,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2013,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -115,7 +115,6 @@ sub parse_options
 sub set_options
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  my $roptions=$rd->set('options');
  return unless (defined($roptions) && (ref($roptions) eq 'HASH') && keys(%$roptions));
@@ -128,10 +127,9 @@ sub set_options
   $options{$d}=$roptions->{'naptr_application_'.$d};
  }
 
- return unless keys(%options);
+ return unless keys %options;
 
- my $eid=$mes->command_extension_register('ienum43','update');
- $mes->command_extension($eid,[['ienum43:options',['ienum43:naptr-application',\%options]]]);
+ $epp->message()->command_extension('ienum43',['update', ['options', ['naptr-application', \%options]]]);
  return;
 }
 
