@@ -1,7 +1,7 @@
 ## Domain Registry Interface, Afilias EPP Renew Redemption Period Extension
 ##
 ## Copyright (c) 2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
-## Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -87,12 +87,10 @@ sub setup
 sub renew
 {
  my ($epp, $domain, $rd) = @_;
- my $mes = $epp->message();
 
- return unless Net::DRI::Util::has_key($rd,'rgp');
+ return unless Net::DRI::Util::has_key($rd, 'rgp') && $rd->{'rgp'};
 
- my $eid = $mes->command_extension_register('argp', 'renew');
- $mes->command_extension($eid, ['argp:restore']);
+ $epp->message()->command_extension('argp', ['renew', ['restore']]);
  return;
 }
 
