@@ -1,6 +1,6 @@
-## Allocation Token Mapping for EPP ((RFC8495)
+## Allocation Token Mapping for EPP (RFC8495)
 ##
-## Copyright (c) 2015,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2015,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -65,13 +65,15 @@ sub command
   return unless defined $token;
  }
 
- my $eid = $mes->command_extension_register('allocationToken', $operation eq 'info' ? 'info' : 'allocationToken');
+ my @d = ($operation eq 'info' ? 'info' : 'allocationToken');
  if (defined $token)
  {
   Net::DRI::Exception::usererr_invalid_parameters('Invalid syntax for allocation token: '.$token) unless Net::DRI::Util::xml_is_token($token, 1);
-  $mes->command_extension($eid, $token);
+  push @d, $token;
  }
 
+ $mes->command_extension('allocationToken', \@d);
+
  return;
 }
 
@@ -121,7 +123,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2015,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2015,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
