@@ -1,6 +1,6 @@
 ## EPP Mapping for Art Record Extension (draft-brown-epp-artRecord-00)
 ##
-## Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -91,8 +91,7 @@ sub command
  Net::DRI::Exception::usererr_invalid_parameters('Invalid syntax for art record "reference": '.$art->{reference}) unless Net::DRI::Util::xml_is_token($art->{reference}, 0, 255);
  push @art, ['artRecord:reference',$art->{reference}];
 
- my $eid=$mes->command_extension_register('artRecord',$operation);
- $mes->command_extension($eid,\@art);
+ $mes->command_extension('artRecord', [$operation, @art]);
 
  return;
 }
@@ -154,7 +153,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
