@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Price Extension Mapping for EPP
 ##
-## Copyright (c) 2015,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2015,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -55,13 +55,11 @@ sub implements { return 'https://ausregistry.github.io/doc/price-1.2/price-1.2.h
 sub check_build
 {
  my ($epp,$domain,$rp)=@_;
- my $mes=$epp->message();
 
  return unless Net::DRI::Util::has_key($rp,'price');
  return unless $rp->{price};
 
- my $eid=$mes->command_extension_register('price','check');
- $mes->command_extension($eid,Net::DRI::Protocol::EPP::Util::build_period($rp->{price},'price')) if Net::DRI::Util::is_class($rp->{price},'DateTime::Duration');
+ $epp->message()->command_extension('price', ['check', Net::DRI::Protocol::EPP::Util::build_period($rp->{price}, 'price')]) if Net::DRI::Util::is_class($rp->{price}, 'DateTime::Duration');
 
  return;
 }
@@ -105,14 +103,12 @@ sub check_parse
 sub _build
 {
  my ($epp,$domain,$rp,$topname)=@_;
- my $mes=$epp->message();
 
  return unless Net::DRI::Util::has_key($rp,'price');
  return unless $rp->{price};
  Net::DRI::Exception::usererr_invalid_parameters('if provided, price element must be "ack" or a decimal number') unless $rp->{price}=~m/^(?:ack|\d+(?:\.\d+)?)$/;
 
- my $eid=$mes->command_extension_register('price',$topname);
- $mes->command_extension($eid,['price:ack',$rp->{price} ne 'ack' ? ['price:price', 0+$rp->{price}] : ()]);
+ $epp->message()->command_extension('price', [$topname, ['ack', $rp->{price} ne 'ack' ? ['price', 0+$rp->{price}] : ()]]);
  return;
 }
 
@@ -161,7 +157,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2015,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2015,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
