@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT Contact EPP extension commands
 ##
-## Copyright (c) 2006,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -45,7 +45,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -88,30 +88,24 @@ sub add_puntcat_extension
 
 sub create
 {
- my ($epp,$contact)=@_;
- my $mes=$epp->message();
- 
- my @n=add_puntcat_extension($contact);
- return unless @n;
+ my ($epp, $contact)=@_;
+
+ my @n = add_puntcat_extension($contact);
+ $epp->message()->command_extension('cx', ['create', @n]) if @n;
 
- my $eid=$mes->command_extension_register('cx', 'create');
- $mes->command_extension($eid,\@n);
  return;
 }
 
 sub update
 {
- my ($epp,$domain,$todo)=@_;
- my $mes=$epp->message();
+ my ($epp, $domain, $todo)=@_;
 
  my $newc=$todo->set('info');
  return unless $newc; ## if there already verified in Core
 
- my @n=add_puntcat_extension($newc);
- return unless @n;
+ my @n = add_puntcat_extension($newc);
+ $epp->message()->command_extension('cx', ['update', ['chg', @n]]) if @n;
 
- my $eid=$mes->command_extension_register('cx', 'update');
- $mes->command_extension($eid,['cx:chg',@n]);
  return;
 }
 
