@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Bundling Registration Extension Mapping for EPP
 ##
-## Copyright (c) 2015-2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2015-2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -43,12 +43,12 @@ sub register_commands
 sub setup
 {
  my ($class,$po,$version)=@_;
- state $ns = { 'b-dn' => 'urn:ietf:params:xml:ns:epp:b-dn-1.0' };
+ state $ns = { 'b-dn' => 'urn:ietf:params:xml:ns:epp:b-dn' };
  $po->ns($ns);
  return;
 }
 
-sub implements { return 'https://tools.ietf.org/id/draft-ietf-regext-bundling-registration-08'; }
+sub implements { return 'https://tools.ietf.org/id/draft-ietf-regext-bundling-registration-10'; }
 
 ####################################################################################################
 
@@ -90,9 +90,8 @@ sub create
  my ($epp,$domain,$rp)=@_;
  my $mes=$epp->message();
 
- my $eid=$mes->command_extension_register('b-dn','create');
  Net::DRI::Exception::usererr_invalid_parameters('ulabel property is mandatory for create with bundling extension') unless Net::DRI::Util::has_key($rp, 'ulabel');
- $mes->command_extension($eid, [ 'b-dn:rdn', { uLabel => $rp->{ulabel} }, $domain]);
+ $mes->command_extension('b-dn', ['create', [ 'rdn', { uLabel => $rp->{ulabel} }, $domain]]);
  return;
 }
 
@@ -105,7 +104,7 @@ __END__
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::CNNIC::Bundling - EPP Bundling Registration Extension mapping (draft-kong-eppext-bundling-registration-08) for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::CNNIC::Bundling - EPP Bundling Registration Extension mapping (draft-kong-eppext-bundling-registration-10) for Net::DRI
 
 =head1 DESCRIPTION
 
@@ -129,7 +128,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2015-2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2015-2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
