@@ -1,7 +1,7 @@
 ## Domain Registry Interface, .COOP Contact EPP extension commands
 ## (based on document: EPP Extensions for the .coop TLD Registrant Verification version 1.6)
 ##
-## Copyright (c) 2006,2008,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2013-2014,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2013-2014,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -107,9 +107,7 @@ sub create
 
  return unless @n;
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('coop', 'create');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('coop', ['create', @n]);
  return;
 }
 
@@ -124,9 +122,7 @@ sub update
  push @n,['coop:chg',\@nn] if @nn;
  return unless @n;
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('coop', 'update');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('coop', ['update', @n]);
  return;
 }
 
