@@ -1,6 +1,7 @@
 ## Domain Registry Interface, .CZ Contact EPP extension commands
 ##
 ## Copyright (c) 2008,2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+##               2018 Patrick Mevzek <netdri@dotandco.com>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -52,6 +53,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2008,2010,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
+              2018 Patrick Mevzek <netdri@dotandco.com>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -98,8 +100,7 @@ sub build_command
 	}
 
 	my $tcommand = (ref($command)) ? $command->[0] : $command;
-	$msg->command([$command, 'contact:' . $tcommand,
-		sprintf('xmlns:contact="%s" xsi:schemaLocation="%s %s"',$msg->nsattrs('contact'))]);
+	$msg->command([$command, 'contact:' . $tcommand, $msg->nsattrs('contact')]);
 
 	my @d = map { ['contact:id', $_] } @c;
 	if (($tcommand =~ m/^(?:info|transfer)$/) && ref($contact[0]) &&
