@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Auxiliary Contacts Extension Mapping for EPP
 ##
-## Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -95,11 +95,8 @@ sub create
  my $cs=$rd->{contact};
 
  my @d = _build_contacts($epp, $cs);
- return unless @d;
+ $epp->message()->command_extension('auxcontact', ['create', @d]) if @d;
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('auxcontact', 'create');
- $mes->command_extension($eid, \@d);
  return;
 }
 
@@ -119,9 +116,8 @@ sub update
  push @d,['auxcontact:rem',@del] if @del;
  push @d,['auxcontact:add',@add] if @add;
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('auxcontact', 'update');
- $mes->command_extension($eid, \@d);
+ $epp->message()->command_extension('auxcontact', ['update', @d]) if @d;
+
  return;
 }
 
@@ -158,7 +154,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
