@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Registration Type Extension Mapping for EPP
 ##
-## Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -63,11 +63,8 @@ sub _build
 {
  my ($epp,$domain,$rd,$command)=@_;
  my $regtype = _regtype($rd);
- return unless defined $regtype;
+ $epp->message()->command_extension('regType', [$command, ['type', $regtype]]) if $regtype;
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('regType', $command);
- $mes->command_extension($eid, ['regType:type', $regtype]);
  return;
 }
 
@@ -103,11 +100,8 @@ sub update
  my ($epp,$domain,$todo)=@_;
 
  my $regtype = _regtype({ registration_type => $todo->set('registration_type') });
- return unless defined $regtype;
+ $epp->message()->command_extension('regType', ['update', ['chg', ['type', $regtype]]]) if $regtype;
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('regType', 'update');
- $mes->command_extension($eid, ['regType:chg',['regType:type', $regtype]]);
  return;
 }
 
@@ -144,7 +138,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
