@@ -1,7 +1,7 @@
 ## Domain Registry Interface, CentralNic DNS TTL EPP extension
 ## (http://labs.centralnic.com/epp/ext/ttl.php)
 ##
-## Copyright (c) 2007,2008,2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008,2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007,2008,2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -101,10 +101,7 @@ sub create
 
  return unless (exists($rd->{ttl}) && ((ref($rd->{ttl}) && Net::DRI::Util::is_class($rd->{ttl},'DateTime::Duration')) || $rd->{ttl}=~m/^\d+$/));
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('ttl', 'create');
- my @n=(['ttl:secs',ref($rd->{ttl})? $rd->{ttl}->in_units('seconds') : $rd->{ttl}]);
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('ttl', ['create', ['secs', ref $rd->{ttl} ? $rd->{ttl}->in_units('seconds') : $rd->{ttl}]]);
  return;
 }
 
@@ -115,10 +112,7 @@ sub update
  my $toset=$todo->set('ttl');
  return unless (defined $toset && ((ref $toset && Net::DRI::Util::is_class($toset,'DateTime::Duration')) || $toset=~m/^\d+$/));
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('ttl', 'update');
- my @n=(['ttl:secs',ref($toset)? $toset->in_units('seconds') : $toset]);
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('ttl', ['update', ['secs', ref $toset ? $toset->in_units('seconds') : $toset]]);
  return;
 }
 
