@@ -1,7 +1,7 @@
 ## Domain Registry Interface, CentralNic Web Forwarding EPP extension
 ## (http://labs.centralnic.com/epp/ext/wf.php)
 ##
-## Copyright (c) 2007,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -47,7 +47,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -100,10 +100,7 @@ sub create
 
  return unless (exists($rd->{web_forwarding}) && defined($rd->{web_forwarding}));
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('wf', 'create');
- my @n=(['wf:url',$rd->{web_forwarding}]);
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('wf', ['create', ['url', $rd->{web_forwarding}]]);
  return;
 }
 
@@ -114,10 +111,7 @@ sub update
  my $toset=$todo->set('web_forwarding');
  return unless defined($toset);
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('wf', 'update');
- my @n=(['wf:url',$toset]);
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('wf', ['update', ['url',$toset]]);
  return;
 }
 
