@@ -1,4 +1,4 @@
-## Domain Registry Interface, Change Poll Extension Mapping for EPP
+## Domain Registry Interface, Change Poll Extension Mapping for EPP (RFC8590)
 ##
 ## Copyright (c) 2015,2016,2018,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
@@ -39,7 +39,7 @@ sub setup
  return;
 }
 
-sub implements { return 'https://tools.ietf.org/html/draft-ietf-regext-change-poll-12'; }
+sub implements { return 'https://tools.ietf.org/html/rfc8590'; }
 
 ####################################################################################################
 
@@ -91,7 +91,7 @@ __END__
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::ChangePoll - EPP Change Poll Extension mapping (draft-ietf-regext-change-poll-12) for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::ChangePoll - EPP Change Poll Extension mapping (RFC8590) for Net::DRI
 
 =head1 DESCRIPTION
 
