@@ -1,7 +1,7 @@
 ## Domain Registry Interface, CoCCA IP Protection
 ## from http://cocca.org.nz/index.php/cocca-tools/extensions.html
 ##
-## Copyright (c) 2011,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2011,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2011,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2011,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -85,7 +85,6 @@ sub setup
 sub create
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  my @ipv;
 
@@ -129,8 +128,7 @@ sub create
 
  return unless @ipv;
 
- my $eid=$mes->command_extension_register('cocca','extension');
- $mes->command_extension($eid,[@ipv]);
+ $epp->message()->command_extension('cocca', ['extension', @ipv]);
  return;
 }
 
