@@ -1,6 +1,6 @@
 ## EPP Mapping for DNAME delegation of domain names (draft-bortzmeyer-regext-epp-dname-02)
 ##
-## Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -59,9 +59,7 @@ sub command
 
  Net::DRI::Exception::usererr_invalid_parameters('Invalid syntax for DNAME: '.$dname) unless Net::DRI::Util::xml_is_token($dname, 1, 255);
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('dnameDeleg','dnameTarget');
- $mes->command_extension($eid,$dname);
+ $epp->message()->command_extension('dnameDeleg',['dnameTarget', $dname]);
 
  return;
 }
@@ -112,7 +110,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
