@@ -1,7 +1,7 @@
 ## Domain Registry Interface, DNSBE Domain EPP extension commands
 ## (based on Registration_guidelines_v4_7_2-Part_4-epp.pdf)
 ##
-## Copyright (c) 2006-2010,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006-2010,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##           (c) 2013 Michael Holloway <michael@thedarkwinter.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -54,7 +54,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006-2010,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
           (c) 2013 Michael Holloway <michael@thedarkwinter.com>.
 All rights reserved.
 
@@ -72,7 +72,7 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- my %tmp=( 
+ my %tmp=(
           create            => [ \&create, undef ],
           update            => [ \&update, undef ],
           info              => [ undef, \&info_parse ],
@@ -101,9 +101,7 @@ sub create
  return unless exists($rd->{nsgroup});
  my @n=add_nsgroup($rd->{nsgroup});
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('dnsbe', 'ext');
- $mes->command_extension($eid,['dnsbe:create',['dnsbe:domain',@n]]);
+ $epp->message()->command_extension('dnsbe', ['ext', ['create', ['domain', @n]]]);
  return;
 }
 
@@ -124,9 +122,7 @@ sub update
  push @n,['dnsbe:add',add_nsgroup($nsgadd)] if $nsgadd;
  push @n,['dnsbe:rem',add_nsgroup($nsgdel)] if $nsgdel;
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('dnsbe', 'ext');
- $mes->command_extension($eid,['dnsbe:update',['dnsbe:domain',@n]]);
+ $epp->message()->command_extension('dnsbe', ['ext', ['update', ['domain', @n]]]);
  return;
 }
 
@@ -158,21 +154,16 @@ sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 
  Net::DRI::Util::check_isa($rd->{deleteDate},'DateTime');
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('dnsbe', 'ext');
- my @n=('dnsbe:delete',['dnsbe:domain',['dnsbe:deleteDate',$rd->{deleteDate}->set_time_zone('UTC')->strftime("%Y-%m-%dT%T.%NZ")]]);
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('dnsbe', ['ext', ['delete', ['domain', ['deleteDate', $rd->{deleteDate}->set_time_zone('UTC')->strftime("%Y-%m-%dT%T.%NZ")]]]]);
  return;
 }
 
 sub transfer_request
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
+ my $mes = $epp->message();
 
- my @n=add_transfer($epp,$mes,$domain,$rd);
- my $eid=$mes->command_extension_register('dnsbe', 'ext');
- $mes->command_extension($eid,['dnsbe:transfer',['dnsbe:domain',@n]]);
+ $mes->command_extension('dnsbe', ['ext', ['transfer', ['domain', add_transfer($epp, $mes, $domain, $rd)]]]);
  return;
 }
 
@@ -250,9 +241,7 @@ sub transferq_request
  push @d,Net::DRI::Protocol::EPP::Util::build_period($rd->{period}) if Net::DRI::Util::has_duration($rd);
  $mes->command_body(\@d);
 
- my @n=add_transfer($epp,$mes,$domain,$rd);
- my $eid=$mes->command_extension_register('dnsbe', 'ext');
- $mes->command_extension($eid,['dnsbe:transferq',['dnsbe:domain',@n]]);
+ $mes->command_extension('dnsbe', ['ext', ['transferq', ['domain', add_transfer($epp, $mes, $domain, $rd)]]]);
  return;
 }
 
@@ -262,10 +251,8 @@ sub trade
  my $mes=$epp->message();
  my @d=Net::DRI::Protocol::EPP::Util::domain_build_command($mes,['trade',{'op'=>'request'}],$domain);
  $mes->command_body(\@d);
+ $mes->command_extension('dnsbe', ['ext', ['trade', ['domain', add_transfer($epp, $mes, $domain, $rd)]]]);
 
- my @n=add_transfer($epp,$mes,$domain,$rd);
- my $eid=$mes->command_extension_register('dnsbe', 'ext');
- $mes->command_extension($eid,['dnsbe:trade',['dnsbe:domain',@n]]);
  return;
 }
 
@@ -281,12 +268,12 @@ sub reactivate
 sub request_authcode
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('dnsbe', 'ext');
+ my $mes = $epp->message();
+
  my @d;
  push @d,['dnsbe:domainName',$domain];
  push @d,['dnsbe:url',$rd->{'url'}] if $rd->{'url'};
- $mes->command_extension($eid,['dnsbe:command',['dnsbe:requestAuthCode',@d],['dnsbe:clTRID',$mes->cltrid()]]);
+ $mes->command_extension('dnsbe', ['ext', ['command', ['requestAuthCode', @d], ['clTRID', $mes->cltrid()]]]);
  # missing TRID
  return;
 }
