@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EURid EPP extensions
 ##
-## Copyright (c) 2005,2007-2012 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2007-2012,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##               2014 Michael Kefeder <michael.kefeder@world4you.com>.
 ##
 ## This file is part of Net::DRI
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2007-2012 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2007-2012i,2018 Patrick Mevzek <netdri@dotandco.com>.
               2014 Michael Kefeder <michael.kefeder@world4you.com>.
 All rights reserved.
 
@@ -71,9 +71,9 @@ sub setup
  my $version=$self->version();
 
 ## NOT handled : dss, dynUpdate, euridcom
-# $self->ns({_main => ['http://www.eurid.eu/xml/epp/epp-1.0','epp-1.0.xsd']});
-# $self->ns({ map { $_ => ['http://www.eurid.eu/xml/epp/'.$_.'-1.0',$_.'-1.0.xsd'] } qw/extendedInfo pendingTransaction/ });
- $self->ns({ map { $_ => ['http://www.eurid.eu/xml/epp/'.$_.'-1.1',$_.'-1.1.xsd'] } qw/nsgroup/ });
+# $self->ns({epp => 'http://www.eurid.eu/xml/epp/epp-1.0'});
+# $self->ns({ map { $_ => 'http://www.eurid.eu/xml/epp/'.$_.'-1.0' } qw/extendedInfo pendingTransaction/ });
+ $self->ns({ map { $_ => 'http://www.eurid.eu/xml/epp/'.$_.'-1.1' } qw/nsgroup/ });
  $self->capabilities('contact_update','status',undef); ## No changes in status possible for .EU domains/contacts
  $self->capabilities('domain_update','status',undef);
  $self->capabilities('domain_update','nsgroup',[ 'add','del']);
