@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EURid Contact EPP extension commands
 ## (based on EURid registration_guidelines_v1_0E-epp.pdf)
 ##
-## Copyright (c) 2005,2008,2012,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2008,2012,2013,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##               2014 Michael Kefeder <michael.kefeder@world4you.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2008,2012,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2008,2012,2013,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
               2014 Michael Kefeder <michael.kefeder@world4you.com>.
 All rights reserved.
 
@@ -91,7 +91,6 @@ sub setup
 sub create
 {
  my ($epp,$contact)=@_;
- my $mes=$epp->message();
 
  ## validate() has been called, we are sure that type & lang exists
  my @n;
@@ -99,15 +98,13 @@ sub create
  push @n,['contact-ext:vat',$contact->vat()] if $contact->vat();
  push @n,['contact-ext:lang',$contact->lang()];
 
- my $eid=$mes->command_extension_register('contact-ext','create');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('contact-ext', ['create', @n]);
  return;
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
- my $mes=$epp->message();
 
  my $newc=$todo->set('info');
  return unless ($newc && (defined($newc->vat()) || defined($newc->lang())));
@@ -116,8 +113,7 @@ sub update
  push @n,['contact-ext:vat',$newc->vat()]   if defined($newc->vat());
  push @n,['contact-ext:lang',$newc->lang()] if defined($newc->lang());
 
- my $eid=$mes->command_extension_register('contact-ext','update');
- $mes->command_extension($eid,['contact-ext:chg',@n]);
+ $epp->message()->command_extension('contact-ext', ['update', ['chg', @n]]);
  return;
 }
 
