@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EURid Domain EPP extension commands
 ## (based on EURid registration_guidelines_v1_0E-epp.pdf)
 ##
-## Copyright (c) 2005-2013,2015,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2013,2015,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##               2014 Michael Kefeder <michael.kefeder@world4you.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -51,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2013,2015,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2013,2015,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
               2014 Michael Kefeder <michael.kefeder@world4you.com>.
 All rights reserved.
 
@@ -100,7 +100,6 @@ sub setup
 sub create
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
  my $cs=$rd->{contact};
 
  my @n;
@@ -111,15 +110,13 @@ sub create
 
  return unless @n;
 
- my $eid=$mes->command_extension_register('domain-ext','create');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('domain-ext', ['create', @n]);
  return;
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
- my $mes=$epp->message();
 
  if (grep { ! /^(?:add|del)$/ } $todo->types('nsgroup'))
  {
@@ -151,20 +148,17 @@ sub update
 
  return unless @n;
 
- my $eid=$mes->command_extension_register('domain-ext','update');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('domain-ext', ['update', @n]);
  return;
 }
 
 sub info
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  return unless Net::DRI::Util::has_key($rd,'authinfo_request') && $rd->{authinfo_request};
 
- my $eid=$mes->command_extension_register('authInfo','info');
- $mes->command_extension($eid,['authInfo:request']);
+ $epp->message()->command_extension('authInfo', ['info', ['request']]);
  return;
 }
 
@@ -266,7 +260,6 @@ sub check_parse
 sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  my $hasdelete=Net::DRI::Util::has_key($rd,'deleteDate') ? 1 : 0;
  my $hascancel=(Net::DRI::Util::has_key($rd,'cancel') && $rd->{cancel}) ? 1 : 0;
@@ -274,7 +267,6 @@ sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
  return unless $hasdelete || $hascancel;
  Net::DRI::Exception::usererr_invalid_parameters('For domain_delete, parameters deleteDate & cancel can not be set at the same time') if $hasdelete && $hascancel;
 
- my $eid=$mes->command_extension_register('domain-ext','delete');
  my @n;
 
  if ($hasdelete)
@@ -287,16 +279,14 @@ sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
   @n=(['domain-ext:cancel']);
  }
 
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('domain-ext', ['delete', @n]);
  return;
 }
 
 sub transfer_request
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
- my $eid=$mes->command_extension_register('domain-ext','transfer');
  my @d;
 
  if (Net::DRI::Util::has_contact($rd))
@@ -315,7 +305,7 @@ sub transfer_request
  ## TODO keygroup
  ##  push @n,['eurid:keygroup',$rd->{keygroup}] if Net::DRI::Util::has_key($rd,'keygroup') && Net::DRI::Util::xml_is_token($rd->{keygroup},1,100);
 
- $mes->command_extension($eid,['domain-ext:request',@d]);
+ $epp->message()->command_extension('domain-ext', ['transfer', ['request', @d]]);
 
  if ($epp->has_module('Net::DRI::Protocol::EPP::Extensions::SecDNS'))
  {
