@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EURid Sunrise EPP extension for Net::DRI
 ## (from registration_guidelines_v1_0F-appendix2-sunrise.pdf )
 ##
-## Copyright (c) 2005,2007-2010,2012,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2007-2010,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -55,7 +55,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2007-2010,2012,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2007-2010,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -206,8 +206,7 @@ sub apply
  if (exists($rd->{nsgroup}))
  {
   my @n=Net::DRI::Protocol::EPP::Extensions::EURid::Domain::add_nsgroup($rd->{nsgroup});
-  my $eid=$mes->command_extension_register('domain-ext','ext');
-  $mes->command_extension($eid,['domain-ext:apply',['domain-ext:domain',@n]]);
+  $epp->message()->command_extension('domain-ext', ['ext', ['apply', ['domain', @n]]]);
  }
  return;
 }
