@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP IDN (draft-ietf-eppext-idnmap-02)
 ##
-## Copyright (c) 2013,2015,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2013,2015,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -69,7 +69,6 @@ sub info_parse
 sub create_build
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  return unless $domain=~m/^xn--/;
  Net::DRI::Exception::usererr_insufficient_parameters('For IDNs, an idn_table must be provided') unless Net::DRI::Util::has_key($rd,'idn_table');
@@ -82,8 +81,7 @@ sub create_build
   push @d,['idn:uname',$rd->{uname}];
  }
 
- my $eid=$mes->command_extension_register('idn','data');
- $mes->command_extension($eid,\@d);
+ $epp->message()->command_extension('idn' , ['data', @d]);
 
  return;
 }
@@ -121,7 +119,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2013,2015,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+Copyright (c) 2013,2015,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
