@@ -2,7 +2,7 @@
 ##
 ## Copyright (c) 2010,2013-2015 HEXONET GmbH, http://www.hexonet.net,
 ##                    Jens Wagner <info@hexonet.net>
-## Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ## All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -55,7 +55,7 @@ Jens Wagner, E<lt>jwagner@hexonet.netE<gt>
 Copyright (c) 2010,2013-2015 HEXONET GmbH, E<lt>http://www.hexonet.netE<gt>,
 Alexander Biehl <abiehl@hexonet.net>,
 Jens Wagner <jwagner@hexonet.net>
-Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>
+Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -102,11 +102,7 @@ sub create_keyvalue_extension
 {
  my ($epp,$hash)=@_;
 
- my $mes=$epp->message();
-
- my $eid=$mes->command_extension_register('keyvalue', 'extension');
-
- my @kv = ();
+ my @kv;
 
  foreach my $key ( sort { $a cmp $b } keys %{$hash} ) {
   my $value = $hash->{$key};
@@ -118,7 +114,7 @@ sub create_keyvalue_extension
   }
  }
  return unless @kv;
- $mes->command_extension($eid,\@kv);
+ $epp->message()->command_extension('keyvalue', ['extension', @kv]);
  return;
 }
 
@@ -126,7 +122,6 @@ sub create_keyvalue_extension
 sub create_keyvalue
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  return unless Net::DRI::Util::has_key($rd,'keyvalue');
 
