@@ -1,6 +1,7 @@
 ## Domain Registry Interface, .IT Contact EPP extension
 ##
 ## Copyright (C) 2009-2010,2013,2016 Tower Technologies. All rights reserved.
+##           (c) 2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License v2.
@@ -31,6 +32,7 @@ Alessandro Zummo, E<lt>a.zummo@towertech.itE<gt>
 =head1 COPYRIGHT
 
 Copyright (C) 2009-2010,2013,2016 Tower Technologies.
+Copyright (c) 2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -81,10 +83,7 @@ sub fix_contact
 
        if (@ext)
        {
-	       my $msg = $epp->message;
-               my $eid = $msg->command_extension_register('extcon', $op);
-
-       	       $msg->command_extension($eid, [ @ext ]);
+       	       $epp->message()->command_extension('extcon', [$op, @ext]);
        }
        return;
 }
