@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .LU Contact EPP extension commands
 ##
-## Copyright (c) 2007,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2007,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -47,7 +47,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2007,2008,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -133,7 +133,6 @@ sub build_disclose
 sub create
 {
  my ($epp,$contact)=@_;
- my $mes=$epp->message();
 
  ## validate() has been called, we are sure that type exists
  my @n;
@@ -141,23 +140,20 @@ sub create
  my $rd=build_disclose($contact->disclose(),$contact->type());
  push @n,['dnslu:disclose',@$rd] if $rd;
 
- my $eid=$mes->command_extension_register('dnslu', 'ext');
- $mes->command_extension($eid,['dnslu:create',['dnslu:contact',@n]]);
+ $epp->message()->command_extension('dnslu', ['ext', ['create', ['contact', @n]]]);
  return;
 }
 
 sub update
 {
  my ($epp,$domain,$todo)=@_;
- my $mes=$epp->message();
 
  my @n;
  push @n,['dnslu:add',['dnslu:disclose',@{build_disclose($todo->add('disclose'),'contact')}]] if $todo->add('disclose');
  push @n,['dnslu:rem',['dnslu:disclose',@{build_disclose($todo->del('disclose'),'contact')}]] if $todo->del('disclose');
  return unless @n;
 
- my $eid=$mes->command_extension_register('dnslu', 'ext');
- $mes->command_extension($eid,['dnslu:update',['dnslu:contact',@n]]);
+ $epp->message()->command_extension('dnslu', ['ext', ['update', ['contact', @n]]]);
  return;
 }
 
