@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .MOBI EPP extensions
 ##
-## Copyright (c) 2006,2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008-2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -47,7 +47,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008-2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008-2010,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -64,9 +64,9 @@ See the LICENSE file that comes with this distribution for more details.
 sub setup
 {
  my ($self,$rp)=@_;
- $self->ns({mobi      => ['urn:afilias:params:xml:ns:ext:mobi-1.0','mobi-1.0.xsd'],
-            trademark => ['urn:afilias:params:xml:ns:ext:mobi-trademark-1.0','mobi-trademark-1.0.xsd'],
-            oxrs      => ['urn:afilias:params:xml:ns:oxrs-1.1','oxrs-1.1.xsd'],
+ $self->ns({mobi      => 'urn:afilias:params:xml:ns:ext:mobi-1.0',
+            trademark => 'urn:afilias:params:xml:ns:ext:mobi-trademark-1.0',
+            oxrs      => 'urn:afilias:params:xml:ns:oxrs-1.1',
            });
  $self->capabilities('domain_update','maintainer_url',['set']);
  return;
