@@ -1,6 +1,6 @@
 ## Domain Registry Interface, NORID (.NO) EPP extensions
 ##
-## Copyright (c) 2008-2013 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+## Copyright (c) 2008-2013,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>
 ## Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>.
 ##                    All rights reserved.
@@ -52,7 +52,7 @@ Trond Haugen, E<lt>info@norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2013 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+Copyright (c) 2008-2013,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen E<lt>info@norid.noE<gt>
 Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>
 All rights reserved.
@@ -83,13 +83,14 @@ sub setup {
     $self->capabilities('host_update','contact',['set']);
     $self->capabilities('host_update','facets',['set']);
     $self->capabilities('domain_update','facets',['set']);
+    $self->capabilities('domain_update','status',['add','del']);
     $self->capabilities('domain_update','applicantdataset',['set']);
     $self->factories('contact',sub { return Net::DRI::Data::Contact::NO->new(); });
 
     return;
 }
 
-sub default_extensions { return qw/NO::Domain NO::Contact NO::Host NO::Result NO::Message/; }
+sub default_extensions { return qw/NO::Domain NO::Contact NO::Host NO::Result NO::Message SecDNS/; }
 
 ####################################################################################################
 1;
