@@ -2,7 +2,7 @@
 ##
 ## Copyright (c) 2008,2010 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>
-##           (c) 2016 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
+##           (c) 2016,2019 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -54,7 +54,7 @@ Trond Haugen, E<lt>info@norid.noE<gt>
 
 Copyright (c) 2008,2010 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen E<lt>info@norid.noE<gt>
-Copyright (c) 2016 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
+Copyright (c) 2016,2019 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -211,7 +211,6 @@ sub facet {
 
 sub add_no_extensions {
     my ( $epp, $contact, $op ) = @_;
-    my $mes = $epp->message();
 
     my $ty  = $contact->type();
     my $id  = $contact->identity();
@@ -232,8 +231,6 @@ sub add_no_extensions {
        || defined($fs)
        );
 
-
-    my $eid = $mes->command_extension_register('no-ext-contact', $op );
     my @e;
 
     push @e, [ 'no-ext-contact:type', $ty ] if ( defined($ty) && $ty );
@@ -310,7 +307,7 @@ sub add_no_extensions {
             [ 'no-ext-contact:disclose', @d, { flag => ( keys(%v) )[0] } ];
 	}
     }
-    my $r = $mes->command_extension( $eid, \@e );
+    my $r = $epp->message()->command_extension( 'no-ext-contact', [ $op, @e ] );
 
     # Add facet if any is set
     if ($fs) {
@@ -329,7 +326,6 @@ sub create {
 
 sub update {
     my ( $epp, $co, $todo ) = @_;
-    my $mes = $epp->message();
 
     my $r;
     my $mp = $todo->set('mobilephone');
@@ -367,8 +363,6 @@ sub update {
         || $xetodel
         || $xd) {
 
-       my $eid = $mes->command_extension_register('no-ext-contact', 'update' );
-
        my ( @n, @s );
 
        if ( defined($mp) ) {
@@ -436,7 +430,7 @@ sub update {
                if ($rctodel);
            push @n, [ 'no-ext-contact:rem', @s ] if ( @s > 0 );
        }
-       $r = $mes->command_extension( $eid, \@n );
+       $r = $epp->message()->command_extension( 'no-ext-contact', [ 'update', @n ] );
     }
 
     if ($fs) {
