@@ -1,8 +1,8 @@
 ## Domain Registry Interface, .NO Domain extensions
 ##
-## Copyright (c) 2008-2010,2013-2014 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+## Copyright (c) 2008-2010,2013-2014,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>
-##           (c) 2016,2018 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
+##           (c) 2016,2018-2019 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -55,9 +55,9 @@ Trond Haugen, E<lt>info@norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2013-2014 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+Copyright (c) 2008-2010,2013-2014,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen E<lt>info@norid.noE<gt>
-(c) 2016,2018 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
+(c) 2016,2018-2019 Patrick Mevzek E<lt>netdri@dotandco.comE<gt>
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -124,10 +124,6 @@ sub applicant_dataset {
     my $acceptname    = $r->{acceptname};
     my $acceptdate    = $r->{acceptdate};
 
-    my $mes = $epp->message();
-
-    my $eid = $mes->command_extension_register('no-ext-domain', $command);
-
     my @te;
     push @te, [ "no-ext-domain:versionNumber", $versionnumber ];
     push @te, [ "no-ext-domain:acceptName"   , $acceptname ];
@@ -138,7 +134,8 @@ sub applicant_dataset {
     } elsif ($command eq 'update') {
         push @e, [ 'no-ext-domain:chg', [ 'no-ext-domain:applicantDataset', @te ] ];
     }
-    return $mes->command_extension( $eid, \@e );
+    $epp->message()->command_extension( 'no-ext-domain', [ $command, @e ] );
+    return;
 }
 
 sub parse_info {
@@ -223,7 +220,8 @@ sub delete { ## no critic (Subroutines::ProhibitBuiltinHomonyms)
     my $dfr = $rd->{deletefromregistry};
     my $fs  = $rd->{facets};
 
-    return unless ( ( defined($dfd) || defined($dfr) || defined($fs) ) && ( $dfd || $dfr || $fs ) );
+    return unless ( ( defined($ddate) || defined($dfd) || defined($dfr) || defined($fs) ) && (
+                        $ddate || $dfd || $dfr || $fs ) );
 
     if (defined($dfd) && ref($dfd)) { 
          Net::DRI::Util::check_isa($dfd,'DateTime');
@@ -244,12 +242,11 @@ sub delete { ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 
     my $r;
     if ( $dfd || $dfr ) {
-       my $eid = $mes->command_extension_register('no-ext-domain', 'delete');
        my @e;
        push @e, [ 'no-ext-domain:deleteFromDNS', $dfd ] if ( defined($dfd) && $dfd );
        push @e, [ 'no-ext-domain:deleteFromRegistry', $dfr ] if ( defined($dfr) && $dfr );
 
-       $r = $mes->command_extension( $eid, \@e ) if (@e);
+       $r = $epp->message()->command_extension( 'no-ext-domain', [ 'delete', @e ] ) if @e;
     }
     if ($fs) {
        $r = facet($epp, $domain, $rd);
@@ -261,7 +258,6 @@ sub delete { ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 
 sub transfer_request {
     my ( $epp, $domain, $rd ) = @_;
-    my $mes = $epp->message();
 
     my $mp = $rd->{mobilephone};
     my $em = $rd->{email};
@@ -271,7 +267,6 @@ sub transfer_request {
 
     my $r;
     if ($mp || $em) {
-       my $eid = $mes->command_extension_register('no-ext-domain', 'transfer');
 
        my @d;
        push @d,
@@ -282,7 +277,7 @@ sub transfer_request {
 
        my @e;
        push @e, [ 'no-ext-domain:notify', @d ];
-       $r = $mes->command_extension( $eid, \@e );
+       $r = $epp->message()->command_extension( 'no-ext-domain', [ 'transfer', @e ] );
 
     }
     if ($fs) {
@@ -311,11 +306,10 @@ sub withdraw {
 
     my $r;
 
-    my $eid = $mes->command_extension_register( 'no-ext-epp', 'command');
-
     $r=$mes->command_extension(
-        $eid,
-        [   [   'no-ext-epp:withdraw',
+        'no-ext-epp',
+        [   'command',
+            [   'no-ext-epp:withdraw',
                 [   'domain:withdraw', [ 'domain:name', $domain ],
                     {'xmlns:domain' => $mes->nsattrs('no-ext-domain')}
                 ]
@@ -361,8 +355,6 @@ sub transfer_execute {
         $dur = Net::DRI::Protocol::EPP::Util::build_period($du);
     }
 
-    my $eid = $mes->command_extension_register( 'no-ext-epp', 'command');
-
     my $cltrid=$mes->cltrid();
 
     my %domns = ('xmlns:domain' => 'urn:ietf:params:xml:ns:domain-1.0');
@@ -373,8 +365,9 @@ sub transfer_execute {
         && ( ref( $rd->{auth} ) eq 'HASH' ) )
     {
         $r=$mes->command_extension(
-            $eid,
-            [   [   'no-ext-epp:transfer',
+            'no-ext-epp',
+            [   'command',
+                [   'no-ext-epp:transfer',
                     { 'op' => 'execute' },
                     [   'domain:transfer',
                         \%domns,
@@ -390,8 +383,9 @@ sub transfer_execute {
         );
     } elsif ($token) {
         $r=$mes->command_extension(
-            $eid,
-            [   [   'no-ext-epp:transfer',
+            'no-ext-epp',
+            [   'command',
+                [   'no-ext-epp:transfer',
                     { 'op' => 'execute' },
                     [   'domain:transfer', \%domns,
                         [ 'domain:name', $domain ], $dur,
@@ -407,8 +401,9 @@ sub transfer_execute {
         );
    } else {
        $r=$mes->command_extension(
-            $eid,
-            [   [   'no-ext-epp:transfer',
+            'no-ext-epp',
+            [   'command',
+                [   'no-ext-epp:transfer',
                     { 'op' => 'execute' },
                     [   'domain:transfer', \%domns,
                         [ 'domain:name', $domain ], $dur,
