@@ -2,7 +2,7 @@
 ##
 ## Copyright (c) 2008,2010,2013-2014 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>
-## Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>.
+## Copyright (c) 2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -52,7 +52,7 @@ Trond Haugen, E<lt>info@norid.noE<gt>
 
 Copyright (c) 2008,2010,2013-2014 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen E<lt>info@norid.noE<gt>
-Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -88,16 +88,13 @@ sub build_facets {
     my ( $epp, $rd ) = @_;
 
     my @e;
-    my $eid;
 
-    my $mes = $epp->message();
     if (exists($rd->{facets}) && defined($rd->{facets})) {
-       $eid = $mes->command_extension_register('no-ext-epp', 'extended');
        foreach my $fkey (sort { $a cmp $b } keys(%{$rd->{facets}})) {
            push @e, [ 'no-ext-epp:facet', { name => $fkey }, $rd->{facets}->{$fkey} ];
        }
     }
-    return $mes->command_extension( $eid, \@e ) if (@e);
+    $epp->message()->command_extension( 'no-ext-epp', ['extended', @e] ) if @e;
     return;
 }
 
@@ -141,7 +138,6 @@ sub parse_info {
 
 sub info {
     my ( $epp, $ho, $rd ) = @_;
-    my $mes = $epp->message();
 
     my $si;
     $si = $rd->{sponsoringclientid} if (exists($rd->{sponsoringclientid}));
@@ -153,21 +149,17 @@ sub info {
     my $r;
 
     if ($si) {
-       my $eid = $mes->command_extension_register('no-ext-host', 'info' );
-       my @e;
-       push @e, [ 'no-ext-host:sponsoringClientID', $si ];
-       $r = $mes->command_extension( $eid, \@e );
+       $r = $epp->message()->command_extension( 'no-ext-host', ['info', ['sponsoringClientID', $si]] );
     }
     if ($fs) {
        $r = facet( $epp, $ho, $rd );
     }
-       
+
     return $r;
 }
 
 sub create {
     my ( $epp, $ho, $rd ) = @_;
-    my $mes = $epp->message();
 
     return unless ((exists($rd->{contact}) && defined($rd->{contact})) || (exists($rd->{facets}) && defined($rd->{facets})));
 
@@ -175,10 +167,9 @@ sub create {
 
     if (exists($rd->{contact}) && defined($rd->{contact})) {
        my @e;
-       my $eid = $mes->command_extension_register('no-ext-host', 'create' );
        my $c = $rd->{contact};
        my $srid;
- 
+
        if ( ref($c) eq 'ARRAY' ) {
            foreach my $cn (@$c) {
                if (Net::DRI::Util::isa_contact($cn))
@@ -205,7 +196,7 @@ sub create {
                push @e, [ 'no-ext-host:contact', $srid ]; 
            }
        }
-       $r = $mes->command_extension( $eid, \@e );
+       $r = $epp->message()->command_extension( 'no-ext-host', ['create', @e] );
     }
 
     # Add facet if any is set
@@ -218,7 +209,6 @@ sub create {
 
 sub update {
     my ( $epp, $ho, $todo ) = @_;
-    my $mes = $epp->message();
 
     my $ca = $todo->add('contact');
     my $cd = $todo->del('contact');
@@ -229,7 +219,6 @@ sub update {
     my $r;
 
     if ( $ca || $cd ) {
-       my $eid = $mes->command_extension_register('no-ext-host', 'update' );
 
        my ( @n, @e, $c, $srid );
 
@@ -296,7 +285,7 @@ sub update {
        }
           push @n, [ 'no-ext-host:rem', @e ] if ( @e > 0 );
        }
-       $r = $mes->command_extension( $eid, \@n );
+       $r = $epp->message()->command_extension( 'no-ext-host', ['update', @n] );
     }
 
     # Add facet if any is set
