@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .NO Result extension
 ##
-## Copyright (c) 2008,2010,2013 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+## Copyright (c) 2008,2010,2013,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 ##                    Trond Haugen E<lt>info@norid.noE<gt>
 ## Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>.
 ##                    All rights reserved.
@@ -48,7 +48,7 @@ Trond Haugen, E<lt>info@norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2010,2013 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
+Copyright (c) 2008,2010,2013,2019 UNINETT Norid AS, E<lt>http://www.norid.noE<gt>,
 Trond Haugen, E<lt>info@norid.noE<gt>
 Copyright (c) 2016 Patrick Mevzek <netdri@dotandco.com>
 All rights reserved.
@@ -132,6 +132,9 @@ sub parse {
         push @conditions, \%con;
         $mes->add_to_extra_info({from=>'no',type=>'text',message => $con{msg}, %con});
     }
+    # $oname is undef in case of $otype='session', so set it to $otype then
+    # to avoid warnings
+    $oname = $otype unless ($oname);
 
     # Extension results can be returned in all 3 object types
     $rinfo->{$otype}->{$oname}->{conditions} = \@conditions;
