@@ -1,7 +1,7 @@
 ## Domain Registry Interface, Neulevel EPP IDN Language
 ##
 ## Copyright (c) 2009,2013 Jouanne Mickael <grigouze@gandi.net>. All rights reserved.
-## Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -51,7 +51,7 @@ Jouanne Mickael E<lt>grigouze@gandi.netE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2009,2013 Jouanne Mickael <grigouze@gandi.net>.
-Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -88,9 +88,7 @@ sub create
  return unless Net::DRI::Util::has_key($rd,'language');
 
  Net::DRI::Exception::usererr_invalid_parameters('IDN language tag must be of type XML schema language') unless Net::DRI::Util::xml_is_language($rd->{language});
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('neulevel', 'extension');
- $mes->command_extension($eid,['neulevel:unspec', 'IDNLang=' . $rd->{language}]);
+ $epp->message()->command_extension('neulevel', ['extension', ['neulevel:unspec', 'IDNLang=' . $rd->{language}]]);
 
  return;
 }
