@@ -3,7 +3,7 @@
 ##
 ## Copyright (c) 2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
 ##                    All rights reserved.
-## Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -52,7 +52,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2008,2013 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -93,19 +93,16 @@ sub setup
 sub add_uin
 {
  my ($epp, $domain, $rd) = @_;
- my $mes = $epp->message();
 
  return unless Net::DRI::Util::has_key($rd,'uin');
 
- my $eid = $mes->command_extension_register('neulevel', 'extension');
- $mes->command_extension($eid, ['neulevel:unspec', 'UIN=' . $rd->{uin}]);
+ $epp->message()->command_extension('neulevel', ['extension', ['unspec', 'UIN=' . $rd->{uin}]]);
  return;
 }
 
 sub renew
 {
  my ($epp, $domain, $rd) = @_;
- my $mes = $epp->message();
  my @vals = qw(RestoreReasonCode RestoreComment TrueData ValidUse UIN);
  my %info;
  my $comment;
@@ -125,8 +122,7 @@ sub renew
   $info{UIN} = $rd->{uin};
  }
 
- my $eid = $mes->command_extension_register('neulevel', 'extension');
- $mes->command_extension($eid, ['neulevel:unspec', join(' ', map { $_ . '=' . $info{$_} } grep { defined($info{$_}) } @vals)]);
+ $epp->message()->command_extension('neulevel', ['extension', ['unspec', join(' ', map { $_ . '=' . $info{$_} } grep { defined($info{$_}) } @vals)]]);
  return;
 }
 
