@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .UK EPP Domain commands
 ##
-## Copyright (c) 2008-2010,2013-2014,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008-2010,2013-2014,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##           (c) 2013 Michael Holloway <michael@thedarkwinter.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -51,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2013-2014,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008-2010,2013-2014,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
           (c) 2013 Michael Holloway <michael@thedarkwinter.com>.
 All rights reserved.
 
@@ -169,9 +169,7 @@ sub create {
  undef $rd->{'renew-not-required'}; # only for updates
  my @n = domain_nom_ext($rd);
  return unless @n;
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('domain-nom-ext', 'create');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('domain-nom-ext', ['create', @n]);
  return;
 }
 
@@ -184,9 +182,7 @@ sub update {
  return unless $rd;
  my @n = domain_nom_ext($rd);
  return unless @n;
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('domain-nom-ext', 'update');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('domain-nom-ext', ['update', @n]);
  return;
 }
 
