@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Nomulus Allocate Extension Mapping for EPP
 ##
-## Copyright (c) 2017-2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2017-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -82,9 +82,7 @@ sub build
   push @data, ['allocate:notice', @notice];
  }
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('allocate', 'create');
- $mes->command_extension($eid, \@data);
+ $epp->message()->command_extension('allocate', ['create', @data]);
  return;
 }
 
@@ -126,7 +124,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2017-2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2017-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
