@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Nomulus Metadata Extension Mapping for EPP
 ##
-## Copyright (c) 2017-2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2017-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -54,14 +54,12 @@ sub build
  return unless defined $metadata;
 
  my @data;
- push @data, [ 'metadata:reason', $metadata->{'reason'} ] if Net::DRI::Util::has_key($metadata, 'reason');
+ push @data, ['metadata:reason', $metadata->{'reason'} ] if Net::DRI::Util::has_key($metadata, 'reason');
  Net::DRI::Exception::usererr_insufficient_parameters('requested_by_registrar must be defined') unless Net::DRI::Util::has_key($metadata, 'requested_by_registrar');
- push @data, [ 'metadata:requestedByRegistrar', $metadata->{'requested_by_registrar'} ? 'true' : 'false' ];
- push @data, [ 'metadata:anchorTenant', $metadata->{'anchor_tenant'} ? 'true' : 'false' ] if Net::DRI::Util::has_key($metadata, 'anchor_tenant');
+ push @data, ['metadata:requestedByRegistrar', $metadata->{'requested_by_registrar'} ? 'true' : 'false' ];
+ push @data, ['metadata:anchorTenant', $metadata->{'anchor_tenant'} ? 'true' : 'false' ] if Net::DRI::Util::has_key($metadata, 'anchor_tenant');
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('metadata', 'metadata');
- $mes->command_extension($eid, \@data);
+ $epp->message()->command_extension('metadata', ['metadata', @data]);
  return;
 }
 
@@ -103,7 +101,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2017-2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2017-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
