@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Nomulus Superuser Extension Mapping for EPP
 ##
-## Copyright (c) 2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2017-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -56,9 +56,7 @@ sub delete ## no critic (Subroutines::ProhibitBuiltinHomonyms)
  my @data=(['superuser:redemptionGracePeriodDays', $superuser->{redemption_grace_period}->in_units('days')],
            ['superuser:pendingDeleteDays', $superuser->{pending_delete}->in_units('days')]);
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('superuser', 'domainDelete');
- $mes->command_extension($eid, \@data);
+ $epp->message()->command_extension('superuser', ['domainDelete', @data]);
  return;
 }
 
@@ -79,9 +77,7 @@ sub transfer
 
  my @data=($period, ['superuser:automaticTransferLength', $superuser->{transfer_length}]);
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('superuser', 'domainTransferRequest');
- $mes->command_extension($eid, \@data);
+ $epp->message()->command_extension('superuser', ['domainTransferRequest', @data]);
  return;
 }
 
@@ -118,7 +114,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2017-2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2017-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
