@@ -1,6 +1,6 @@
 ## Domain Registry Interface, NASK (.PL) EPP extensions (draft-zygmuntowicz-epp-pltld-03)
 ##
-## Copyright (c) 2006,2008,2009,2012,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2009,2012,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009,2012,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2009,2012,2013,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -66,9 +66,9 @@ See the LICENSE file that comes with this distribution for more details.
 sub setup
 {
  my ($self,$rp)=@_;
- $self->ns({ extdom  => ['http://www.dns.pl/NASK-EPP/extdom-1.0','extdom-1.0.xsd'],
-             extcon => ['http://www.dns.pl/NASK-EPP/extcon-1.0','extcon-1.0.xsd'],
-            # future     => ['http://www.dns.pl/NASK-EPP/future-1.0','future-1.0.xsd'], ## TODO
+ $self->ns({ extdom => 'http://www.dns.pl/NASK-EPP/extdom-1.0',
+             extcon => 'http://www.dns.pl/NASK-EPP/extcon-1.0',
+            # future     => 'http://www.dns.pl/NASK-EPP/future-1.0', ## TODO
           });
  $self->capabilities('host_update','name',undef); ## No change of hostnames
  $self->factories('contact',sub { return Net::DRI::Data::Contact::PL->new(); });
