@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .PL EPP Report extension commands
 ##
-## Copyright (c) 2012,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2012,2013,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -40,7 +40,6 @@ sub setup
 sub create
 {
  my ($epp,$id,$rp)=@_;
- my $mes=$epp->message();
 
  Net::DRI::Exception::usererr_insufficient_parameters('An ID must be provided to track this report results') unless defined $id && length $id;
  Net::DRI::Exception::usererr_insufficient_parameters('An hash ref must be provided with at least a type key') unless Net::DRI::Util::has_key($rp,'type');
@@ -70,8 +69,7 @@ sub create
  push @n,['extreport:offset',$rp->{offset}] if Net::DRI::Util::has_key($rp,'offset') && $rp->{offset}=~m/^\d+$/;
  push @n,['extreport:limit',$rp->{limit}]   if Net::DRI::Util::has_key($rp,'limit')  && $rp->{limit}=~m/^\d+$/;
 
- my $eid=$mes->command_extension_register('extreport','report');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension('extreport', ['report', @n]);
  return;
 }
 
@@ -397,7 +395,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012,2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+Copyright (c) 2012,2013,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
