@@ -1,7 +1,7 @@
 ## Domain Registry Interface, .PRO domain extensions
 ##
 ## Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-##           (c) 2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+##           (c) 2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 ##                    All rights reserved.
 ##
 ## This file is part of Net::DRI
@@ -53,7 +53,7 @@ E<lt>http://www.hexonet.net/E<gt>.
 =head1 COPYRIGHT
 
 Copyright (c) 2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
-          (c) 2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
+          (c) 2010,2013,2016,2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -85,7 +85,6 @@ sub register_commands
 sub add_pro_extinfo
 {
  my ($epp, $domain, $rd) = @_;
- my $mes = $epp->message();
  my @prodata;
  my @tmdata;
  my $pw;
@@ -121,8 +120,7 @@ sub add_pro_extinfo
 	if (exists($ph->{auth}));
  return unless (@prodata);
 
- my $eid = $mes->command_extension_register('rpro', 'proDomain');
- $mes->command_extension($eid, [@prodata]);
+ $epp->message()->command_extension('rpro', ['proDomain', @prodata]);
  return;
 }
 
