@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Command Reversal Extension for EPP
 ##
-## Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -58,8 +58,7 @@ sub build
  push @d, ['reverse:trID', Net::DRI::Util::has_key($rd, 'trid') ? ['reverse:clTRID', $rd->{trid}] : (), ['reverse:svTRID', $svtrid]];
  push @d, ['reverse:clTRID', $mes->cltrid()];
 
- my $eid=$mes->command_extension_register('reverse', 'reverse');
- $mes->command_extension($eid, \@d);
+ $epp->message()->command_extension('reverse', ['reverse', @d]);
 
  return;
 }
@@ -127,7 +126,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
