@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Service Message Extension Mapping for EPP
 ##
-## Copyright (c) 2015 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2015,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -34,7 +34,7 @@ sub register_commands
 sub setup
 {
  my ($class,$po,$version)=@_;
- $po->ns({ 'servicemessage' => [ 'http://tld-box.at/xmlns/resdata-1.1','resdata-1.1.xsd' ] });
+ $po->ns({ 'servicemessage' => 'http://tld-box.at/xmlns/resdata-1.1' });
  return;
 }
 
@@ -134,7 +134,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2015 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2015,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
