@@ -1,7 +1,7 @@
 ## Domain Registry Interface, .RU/.SU/.XN--P1AI EPP REgistrar Extension for Net::DRI
 ##
 ## Copyright (c) 2010-2011 Dmitry Belyavsky <beldmit@gmail.com>
-##               2011-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+##               2011-2014,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -95,7 +95,7 @@ sub update
 	}
 
 	$mes->command(
-			['update','registrar:update',sprintf('xmlns:registrar="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('registrar')),]
+			['update','registrar:update',sprintf('xmlns:registrar="%s"',$mes->nsattrs('registrar')),]
 			);
 	push @d,['registrar:add',@add] if @add;
 	push @d,['registrar:rem',@del] if @del;
@@ -132,7 +132,7 @@ sub info
  my $mes=$epp->message();
 
  $mes->command(
- 	['info','registrar:info',sprintf('xmlns:registrar="%s" xsi:schemaLocation="%s %s"',$mes->nsattrs('registrar')),]
+ 	['info','registrar:info',sprintf('xmlns:registrar="%s"',$mes->nsattrs('registrar')),]
 	);
  $mes->command_body(['registrar:id', $registrar]);
  return;
@@ -253,7 +253,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2010-2011 Dmitry Belyavsky <beldmit@gmail.com>
-Copyright (c) 2011-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2011-2014,2018 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
