@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Telnic (.TEL) EPP extensions
 ##
-## Copyright (c) 2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2013,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -24,9 +24,7 @@ use base qw/Net::DRI::Protocol::EPP/;
 sub setup
 {
  my ($self,$rp)=@_;
- $self->ns({
-            neulevel  => ['urn:ietf:params:xml:ns:neulevel-1.0','neulevel-1.0.xsd'],
-           });
+ $self->ns({ neulevel => 'urn:ietf:params:xml:ns:neulevel-1.0' });
  $self->capabilities('domain_update','whois_type',['set']);
 
  return;
