@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP .US Contact NEXUS Extensions
 ##
-## Copyright (c) 2005,2006,2008,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005,2006,2008,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -48,7 +48,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005,2006,2008,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005,2006,2008,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -112,10 +112,8 @@ sub create
 
  return unless Net::DRI::Util::isa_contact($contact,'Net::DRI::Data::Contact::US');
 
- my $mes=$epp->message();
  my $str=sprintf('AppPurpose=%s NexusCategory=%s',$contact->application_purpose(),$contact->nexus_category());
- my $eid=$mes->command_extension_register('neulevel', 'extension');
- $mes->command_extension($eid,['neulevel:unspec',$str]);
+ $epp->message()->command_extension('neulevel', ['extension', ['neulevel:unspec',$str]]);
  return;
 }
 
@@ -132,9 +130,7 @@ sub update
 
  return unless @tmp;
 
- my $mes=$epp->message();
- my $eid=$mes->command_extension_register('neulevel', 'extension');
- $mes->command_extension($eid,['neulevel:unspec',join(' ',@tmp)]);
+ $epp->message()->command_extension('neulevel', ['extension', ['neulevel:unspec',join(' ',@tmp)]]);
  return;
 }
 
