@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Charge Extension Mapping for EPP
 ##
-## Copyright (c) 2015,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2015,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -121,8 +121,7 @@ sub add_agreement
   push @d,['charge:set',add_set($charge)];
  }
 
- my $eid=$mes->command_extension_register('charge','agreement');
- $mes->command_extension($eid,\@d);
+ $epp->message()->command_extension('charge', ['agreement', @d]);
  return;
 }
 
@@ -235,7 +234,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2015,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2015,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
