@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EPP NameStore Extension for Verisign
 ##
 ## Copyright (c) 2006,2008,2009 Rony Meyer <perl@spot-light.ch>. All rights reserved.
-##               2010,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+##               2010,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -51,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2006,2008,2009 Rony Meyer <perl@spot-light.ch>.
-          (c) 2010,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+          (c) 2010,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -129,17 +129,15 @@ sub add_namestore_ext
  my $mes=$epp->message();
  my $defprod=$epp->default_parameters()->{subproductid};
 
- my $eid=$mes->command_extension_register('namestoreExt','namestoreExt');
-
  if (Net::DRI::Util::has_key($rd,'subproductid') && $rd->{subproductid})
  {
-  $mes->command_extension($eid,['namestoreExt:subProduct',$rd->{subproductid}]);
+  $mes->command_extension('namestoreExt',['namestoreExt', ['subProduct', $rd->{subproductid}]]);
   return;
  }
 
  unless ($defprod eq '_auto_')
  {
-  $mes->command_extension($eid,['namestoreExt:subProduct',$defprod]);
+  $mes->command_extension('namestoreExt',['namestoreExt', ['subProduct', $defprod]]);
   return;
  }
 
@@ -148,7 +146,7 @@ sub add_namestore_ext
  $domain=$domain->[0] if (ref($domain) eq 'ARRAY');
  $ext='dot'.uc($1) if ($domain=~m/\.(net|cc|tv|bz|jobs|edu)$/i);
 
- $mes->command_extension($eid,['namestoreExt:subProduct',$ext]);
+ $mes->command_extension('namestoreExt',['namestoreExt', ['subProduct',$ext]]);
  return;
 }
 
