@@ -1,6 +1,6 @@
 ## Domain Registry Interface, VeriSign EPP Premium Domain Extension
 ##
-## Copyright (c) 2010,2012,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2010,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -48,7 +48,6 @@ sub setup
 sub check
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  my $pd;
  if (Net::DRI::Util::has_key($rd,'premium_domain'))
@@ -67,8 +66,7 @@ sub check
  }
  Net::DRI::Exception::usererr_invalid_parameters('Premium domain flag must be true/false/1/0') unless Net::DRI::Util::xml_is_boolean($pd);
 
- my $eid=$mes->command_extension_register('premiumdomain', 'check');
- $mes->command_extension($eid,['premiumdomain:flag',$pd]);
+ $epp->message()->command_extension('premiumdomain', ['check', ['flag', $pd]]);
  return;
 }
 
@@ -110,9 +108,7 @@ sub update
  my $chg=$todo->set('premium_short_name');
  return unless defined $chg && length $chg;
 
- my $mes=$po->message();
- my $eid=$mes->command_extension_register('premiumdomain', 'reassign');
- $mes->command_extension($eid,['premiumdomain:shortName',$chg]);
+ $po->message()->command_extension('premiumdomain', ['reassign', ['premiumdomain:shortName',$chg]]);
  return;
 }
 
@@ -165,7 +161,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2010,2012,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2010,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
