@@ -1,6 +1,6 @@
 ## Domain Registry Interface, VeriSign Two Factor Auth EPP extension
 ##
-## Copyright (c) 2012,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2012,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -180,7 +180,6 @@ sub domain_update_generate
 
  return unless Net::DRI::Util::has_key($rp,'auth') && ref $rp->{auth} eq 'HASH' && grep { Net::DRI::Util::has_key($rp->{auth},$_); } qw/validate bind unbind/;
 
- my $mes=$epp->message();
  my @n;
 
  if (Net::DRI::Util::has_key($rp->{auth},'validate'))
@@ -230,8 +229,7 @@ sub domain_update_generate
   push @n,['authExt:unbind',@d];
  }
 
- my $eid=$mes->command_extension_register(['authExt','authSession'],'authActions');
- $mes->command_extension($eid,\@n);
+ $epp->message()->command_extension(['authExt', 'authSession'], ['authActions', @n]);
  return;
 }
 
@@ -268,7 +266,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2012,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+Copyright (c) 2012,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
