@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Whois Info (EPP-Whois-Info-Ext.pdf)
 ##
-## Copyright (c) 2006-2008,2012,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006-2008,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008,2012,2013,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006-2008,2012,2013,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -84,7 +84,6 @@ sub setup
 sub info
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
  my $defprod=$epp->default_parameters()->{subproductid};
  return if ($defprod eq '_auto_' && $domain=~m/\.(?:cc|tv)$/i);
 
@@ -105,8 +104,7 @@ sub info
  }
  Net::DRI::Exception::usererr_invalid_parameters('Whois Info must be true/false/1/0') unless Net::DRI::Util::xml_is_boolean($wi);
 
- my $eid=$mes->command_extension_register('whoisInf', 'whoisInf');
- $mes->command_extension($eid,['whoisInf:flag',$wi]);
+ $epp->message()->command_extension('whoisInf', ['whoisInf', ['flag', $wi]]);
  return;
 }
 
