@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Message
 ##
-## Copyright (c) 2005-2014,2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2014,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -60,7 +60,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2014,2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2014,2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -158,36 +158,16 @@ sub result_status
  return Net::DRI::Util::link_rs(@rs);
 }
 
-sub command_extension_register
-{
- my ($self,$ocmd,$ons,$otherattrs)=@_;
-
- $self->{extension}=[] unless exists $self->{extension};
- my $eid=1+$#{$self->{extension}};
- if (defined $ons && $ons!~m/xmlns/) ## new interface, everything should switch to that (TODO)
- {
-  my ($nss,$command)=($ocmd,$ons);
-  $ocmd=(ref $nss eq 'ARRAY' ? $nss->[0] : $nss).':'.$command;
-  $ons=$self->nsattrs($nss);
-  ## This is used for other *generic* attributes, not for xmlns: ones !
-  $ons.=' '.join(' ',map { sprintf('%s="%s"',$_,$otherattrs->{$_}) } sort { $a cmp $b } keys %$otherattrs) if defined $otherattrs && ref $otherattrs eq 'HASH' && keys %$otherattrs;
- } else
- {
-  carp "Use of command_extension_register old API soon to be removed, contact author to update";
- }
- $self->{extension}->[$eid]=[$ocmd,$ons,[]];
- return $eid;
-}
-
 sub command_extension
 {
- my ($self,$eid,$rdata)=@_;
+ my ($self, $ns, $rdata)=@_;
 
- if (defined $eid && $eid >= 0 && $eid <= $#{$self->{extension}} && defined $rdata && (((ref $rdata eq 'ARRAY') && @$rdata) || ($rdata ne '')))
- {
-  $self->{extension}->[$eid]->[2]=(ref($rdata) eq 'ARRAY')? [ @{$self->{extension}->[$eid]->[2]}, @$rdata ] : $rdata;
- }
- return $self->{extension};
+ $self->{extension} = {} unless exists $self->{extension};
+
+ $ns = [ $ns ] unless ref $ns eq 'ARRAY';
+ $self->{extension}->{$ns->[0]} = [ {map { 'xmlns:'.$_ => $self->{ns}->{$_} } @$ns} , @$rdata ];
+
+ return $self;
 }
 
 sub as_string
@@ -228,27 +208,13 @@ sub as_string
 
  ## OPTIONAL extension
  my $ext=$self->{extension};
- if (defined $ext && ref $ext eq 'ARRAY' && @$ext)
+ if (defined $ext && ref $ext eq 'HASH' && keys %$ext)
  {
   push @d,'<extension>';
-  foreach my $e (@$ext)
+  foreach my $ns (sort(keys %$ext))
   {
-   my ($ecmd,$ens,$rdata)=@$e;
-   if ($ecmd && $ens)
-   {
-    if ((ref $rdata && @$rdata) || (! ref $rdata && $rdata ne ''))
-    {
-     push @d,'<',$ecmd,' ',$ens,'>';
-     push @d,ref($rdata)? Net::DRI::Util::xml_write($rdata) : Net::DRI::Util::xml_escape($rdata);
-     push @d,'</',$ecmd,'>';
-    } else
-    {
-     push @d,'<',$ecmd,' ',$ens,'/>';
-    }
-   } else
-   {
-    push @d,Net::DRI::Util::xml_escape(@$rdata);
-   }
+   my $rdata = $ext->{$ns};
+   push @d, Net::DRI::Util::xml_write($rdata, $ns);
   }
   push @d,'</extension>';
  }
