@@ -1,6 +1,6 @@
 ## Domain Registry Interface, OpenSRS XCP Protocol
 ##
-## Copyright (c) 2008-2010,2012 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008-2010,2012,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -50,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008-2010,2012 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008-2010,2012,2013 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -84,7 +84,7 @@ sub _load
 {
  my ($self,$rp)=@_;
  my @class=map { 'Net::DRI::Protocol::OpenSRS::XCP::'.$_ } (qw/Account Domain Host Session/);
- $self->SUPER::_load(@class);
+ return $self->SUPER::_load(@class);
 }
 
 sub transport_default
