@@ -2,6 +2,7 @@
 ##
 ## Copyright (c) 2007,2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>. All rights reserved.
 ##           (c) 2012,2013 Michael Holloway <michael@thedarkwinter.com>. All rights reserved.
+##           (c) 2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -56,6 +57,7 @@ Tonnerre Lombard, E<lt>tonnerre.lombard@sygroup.chE<gt>
 
 Copyright (c) 2007,2008 Tonnerre Lombard <tonnerre.lombard@sygroup.ch>.
           (c) 2012,2013 Michael Holloway <michael@thedarkwinter.com>.
+          (c) 2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -106,8 +108,7 @@ sub build_command
  }
 
  my $tcommand = (ref($command)) ? $command->[0] : $command;
- my @ns = @{$msg->ns->{domain}};
- $msg->command(['domain', $tcommand, (defined($dns) ? $dns : $ns[0]), $domainattr]);
+ $msg->command(['domain', $tcommand, $dns // $msg->ns('domain'), $domainattr]);
 
  my @d;
 
@@ -140,10 +141,11 @@ sub check_parse
  my $mes = $po->message();
  return unless $mes->is_success();
 
- my $chkdata = $mes->get_content('checkData',$mes->ns('domain'));
+ my $ns = $mes->ns('domain');
+ my $chkdata = $mes->get_content('checkData', $ns);
  return unless $chkdata;
- my @d = $chkdata->getElementsByTagNameNS($mes->ns('domain'),'handle');
- my @s = $chkdata->getElementsByTagNameNS($mes->ns('domain'),'status');
+ my @d = $chkdata->getElementsByTagNameNS($ns, 'handle');
+ my @s = $chkdata->getElementsByTagNameNS($ns, 'status');
  return unless (@d && @s);
 
  my $dom = $d[0]->getFirstChild()->getData();
@@ -295,13 +297,12 @@ sub transfer_parse
  my $mes = $po->message();
  return unless $mes->is_success();
 
- my $infodata = $mes->get_content('infoData', $mes->ns('domain'));
+ my $ns = $mes->ns('domain');
+ my $infodata = $mes->get_content('infoData', $ns);
  return unless $infodata;
- my $namedata = ($infodata->getElementsByTagNameNS($mes->ns('domain'),
-	'handle'))[0];
+ my $namedata = ($infodata->getElementsByTagNameNS($ns, 'handle'))[0];
  return unless $namedata;
- my $trndata = ($infodata->getElementsByTagNameNS($mes->ns('domain'),
-	'chprovData'))[0];
+ my $trndata = ($infodata->getElementsByTagNameNS($ns, 'chprovData'))[0];
  return unless $trndata;
 
  $oname = lc($namedata->getFirstChild()->getData());
@@ -344,7 +345,7 @@ sub create
 {
  my ($rri, $domain, $rd) = @_;
  my $mes = $rri->message();
- my %ns = map { $_ => $mes->ns->{$_}->[0] } qw(domain dnsentry xsi);
+ my %ns = map { $_ => $mes->ns($_) } qw(domain dnsentry xsi);
  my @d = build_command($mes, 'create', $domain, undef, \%ns);
  
  my $def = $rri->default_parameters();
@@ -486,7 +487,7 @@ sub transfer_request
 {
  my ($rri, $domain, $rd) = @_;
  my $mes = $rri->message();
- my %ns = map { $_ => $mes->ns->{$_}->[0] } qw(domain dnsentry xsi);
+ my %ns = map { $_ => $mes->ns($_) } qw(domain dnsentry xsi);
  my @d = build_command($mes, 'chprov', $domain, undef, \%ns);
 
  ## Contacts, all OPTIONAL
@@ -515,7 +516,7 @@ sub trade
 {
  my ($rri, $domain, $rd) = @_;
  my $mes = $rri->message();
- my %ns = map { $_ => $mes->ns->{$_}->[0] } qw(domain dnsentry xsi);
+ my %ns = map { $_ => $mes->ns($_) } qw(domain dnsentry xsi);
  my @d = build_command($mes, 'chholder', $domain, undef, \%ns);
 
  my $def = $rri->default_parameters();
@@ -544,7 +545,7 @@ sub transit {
  my ($rri, $domain, $rd) = @_;
  my $mes = $rri->message();
  my $disconnect = ( exists($rd->{disconnect}) && $rd->{disconnect} eq 'true' ) ? { disconnect => 'true'} : undef;
- my %ns = map { $_ => $mes->ns->{$_}->[0] } qw(domain dnsentry xsi);
+ my %ns = map { $_ => $mes->ns($_) } qw(domain dnsentry xsi);
  my @d = build_command($mes, 'transit', $domain, $disconnect, \%ns);
 
  $mes->command_body(\@d);
@@ -554,7 +555,7 @@ sub transit {
 sub migrate_descr {
  my ($rri, $domain, $rd) = @_;
  my $mes = $rri->message();
- my %ns = map { $_ => $mes->ns->{$_}->[0] } qw(domain dnsentry xsi);
+ my %ns = map { $_ => $mes->ns($_) } qw(domain dnsentry xsi);
  my @d = build_command($mes, 'migrate-descr', $domain, undef, \%ns);
 
  ## Contacts, Holder is required
@@ -567,7 +568,7 @@ sub migrate_descr {
 sub create_authinfo {
  my ($rri, $domain, $rd) = @_;
  my $mes = $rri->message();
- my %ns = map { $_ => $mes->ns->{$_}->[0] } qw(domain dnsentry xsi);
+ my %ns = map { $_ => $mes->ns($_) } qw(domain dnsentry xsi);
  my $hash = exists($rd->{'authinfohash'}) ? { hash => $rd->{'authinfohash'}} : undef;
  $hash->{'expire'} = $rd->{'authinfoexpire'} if ($hash && exists($rd->{'authinfoexpire'}));
  my $cmd = ($hash) ? 'createAuthInfo1' : 'createAuthInfo2';
@@ -579,7 +580,7 @@ sub create_authinfo {
 sub delete_authinfo {
  my ($rri, $domain, $rd) = @_;
  my $mes = $rri->message();
- my %ns = map { $_ => $mes->ns->{$_}->[0] } qw(domain dnsentry xsi);
+ my %ns = map { $_ => $mes->ns($_) } qw(domain dnsentry xsi);
  my @d = build_command($mes, 'deleteAuthInfo1', $domain, undef, \%ns);
  $mes->command_body(\@d);
  return;
@@ -589,7 +590,7 @@ sub update
 {
  my ($rri, $domain, $todo, $rd)=@_;
  my $mes = $rri->message();
- my %ns = map { $_ => $mes->ns->{$_}->[0] } qw(domain dnsentry xsi);
+ my %ns = map { $_ => $mes->ns($_) } qw(domain dnsentry xsi);
  my $ns = $rd->{ns};
  my $cs = $rd->{contact};
 
