@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Whois commands for .AT (RFC3912)
 ##
-## Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2008,2009,2013,2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -48,7 +48,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2008,2009,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2008,2009,2013,2014 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -146,7 +146,7 @@ sub parse_contacts
  my %tmp;
 
  ## First pass, only the IDs
- foreach my $t (keys(%t))
+ foreach my $t (sort { $a cmp $b } keys %t)
  {
   my $c=$po->create_local_object('contact');
   my $id=$rr->{$t}->[0];
