@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Misc. useful functions
 ##
-## Copyright (c) 2005-2016,2018 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -52,7 +52,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2016,2018 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2016,2018-2019 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -67,7 +67,7 @@ See the LICENSE file that comes with this distribution for more details.
 
 ####################################################################################################
 
-## See https://www.iso.org/obp/ui/#search , select 'Country codes', then 'Officially assigned', order by Alpha-2 code (last checked on 2018-01-16)
+## See https://www.iso.org/obp/ui/#search , select 'Country codes', then 'Officially assigned', order by Alpha-2 code (last checked on 2019-08-08)
 ##                        qw/.A .B .C .D .E .F .G .H .I .J .K .L .M .N .O .P .Q .R .S .T .U .V .W .X .Y .Z
 our %CCA2=map { $_ => 1 } qw/         AD AE AF AG    AI       AL AM    AO    AQ AR AS AT AU    AW AX    AZ/,
                           qw/BA BB    BD BE BF BG BH BI BJ    BL BM BN BO    BQ BR BS BT    BV BW    BY BZ/,
@@ -527,9 +527,9 @@ sub xml_escape
 
 sub xml_write
 {
- my $rd=shift;
+ my ($rd, $default_ns) = @_;
  my @t;
- foreach my $d (ref $rd->[0] ? @$rd : ($rd)) ## $d is a node=ref array
+ foreach my $d (ref $rd->[0] eq 'ARRAY' ? @$rd : ($rd)) ## $d is a node=ref array
  {
   my @c; ## list of children nodes
   my %attr;
@@ -544,14 +544,23 @@ sub xml_write
    }
   }
   my $tag=shift(@c);
-  my $attr=keys(%attr)? ' '.join(' ',map { $_.'="'.$attr{$_}.'"' } sort { $a cmp $b } keys %attr) : '';
+  if (defined $default_ns && index($tag, ':') == -1)
+  {
+   $tag = $default_ns.':'.$tag;
+  }
+  my $attr = '';
+  if (keys(%attr))
+  {
+   # sort all xmlns first then others
+   $attr = ' '.join(' ',map { $_.'="'.$attr{$_}.'"' } sort { index($b,'xmlns:') <=> index($a,'xmlns:') || $a cmp $b } keys %attr);
+  }
   if (!@c || (@c==1 && !ref($c[0]) && ($c[0] eq '')))
   {
    push @t,'<'.$tag.$attr.'/>';
   } else
   {
    push @t,'<'.$tag.$attr.'>';
-   push @t,(@c==1 && !ref($c[0]))? xml_escape($c[0]) : xml_write(\@c);
+   push @t,(@c==1 && !ref($c[0]))? xml_escape($c[0]) : xml_write(\@c, $default_ns);
    push @t,'</'.$tag.'>';
   }
  }
